array/pop_back.hpp

The array/pop_back.hpp header defines macros to pop an element from the end of an array.

#### Usage

#include <boost/preprocessor/array/pop_back.hpp>

#### Contents

- BOOST_PP_ARRAY_POP_BACK
- BOOST_PP_ARRAY_POP_BACK_Z

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)